check_parsimony_clusters takes a vector clusters of the tips, and
checks whether the number of groups of the tips induced by this allocation is
exactly the number of shifts plus one.
check_parsimony_clusters(tree, edges, clusters)boolean : TRUE if the allocation is parsimonious.
phylogenetic tree.
a vector of clusters of the tips of the tree (result of
function clusters_from_shifts).
This function computes explicitly the clustering of the tips, using
function check_parsimony.
By default, this function uses enumerate_tips_under_edges to compute
the list of tips under each edge, but a list can be provided (if many tests are done).