compute_log_likelihood.simple computes the log-likelihood of the data
in the simple case where the inverse of the variance matrix is given.
compute_log_likelihood.simple(phylo, Y_data_vec, sim, Sigma, Sigma_YY_chol_inv, miss = rep(FALSE, dim(sim)[1] * length(phylo$tip.label)), masque_data = c(rep(TRUE, dim(sim)[1] * length(phylo$tip.label)), rep(FALSE, dim(sim)[1] * phylo$Nnode)), ...)simulatecompute_variance_covariancecompute_mean_variance.simple. It uses functions
extract.variance_covariance, extract.covariance_parents, and
extract_simulate_internal to extract the needed quantities from these objects.