init.incidence.matrix.full: Initialization for incidence matrix (full tree)
Description
init.incidence.matrix.full initialize the matrix updated in
update.incidence.matrix.full for the computation of the incidence
matrix of the full tree in incidence.matrix.full.
Usage
init.incidence.matrix.full(phy)
Value
Matrix of size ntaxa + nNodes.
Details
The initialized matrix is squared of size ntaxa + nNodes. Each node
represent its parental branch. A row corresponding to a tip i is initialized
to a vector of zeros, with only entry i equal to one. (Branch ending at
tip i is only in the i^th lineage)