residuals computes the residuals of some parameters.
# S3 method for PhyloEM
residuals(object, ...)an object of class params_process or PhyloEM.
trait, and each column is a tip. The column names are checked against the
tip names of the tree.
incidence.matrix.full. Can be specified to avoid extra computations.
for a PhyloEM object, further arguments to be passed on to
params_process.PhyloEM (to choose which parameters to extract from
the results, see documentation of this function).
The log likelihood of the data with the provided parameters on the tree.