sum.partitions.cardFixed returns the sum on I subset of [1,p], |I|
fixed, of the sums computed by sum.prod.comb.
"sum"(A, N, K, p, cardI)combn to enumarate all the subsets I of [1,p] of
a given cardinal, and then performs the wanted sum on these subsets.