update.incidence.matrix: Update function for incidence matrix
Description
update.incidence.matrix updates the matrix initialized in
init.incidence.matrix for the computation of the incidence matrix
in incidence.matrix.
Usage
update.incidence.matrix(daughtersParams, ...)
Value
Vector of length ntaxa, indicating to which lineages the branch
above the current node belongs to.
Arguments
- daughtersParams
: rows of updated matrix corresponding to the
daughters of the current node.
Details
A node belongs to all the lineages of its daughters.