update.parsimonyNumber compute the line vector of a parent node, given
the vectors of its daughters.
update.parsimonyNumber(daughters, daughtersParams, cost, ...)A line vector corresponding to the parent node.
the identifiers of the daughters nodes.
a ndaughters x (nclus) matrix with the line vectors of the number of solutions for the daughters nodes.
the (ntaxa + Nnode) x nclus matrix of costs (computed by parsimonyCost).
This function uses function compute_state_filter to find all the admissible
states of the daughters, given a starting state for the parent.