update.partitionsNumber.gen apply the actualization formula to get
Nk and Ak of a node given its daughters.
update.partitionsNumber.gen(daughtersParams, ...): matrix with 2*npart columns. Each row contains the result of partitionsNumber for the children of a given node
vector of size 2*npart. For k=1:npart it contains the number of partitions with k groups compatible with the sub tree starting at the current node ; and for k=(npart+1):2*npart, it contains the number of "marked" partitions with (k-npart) groups compatible with the sub tree starting at the current node.
Uses functions sum.partitions and sum.simplex to compute
the needed sums.