compute_E.simple computes the E step in the simple case where the invert matrix Sigma_YY_inv is given
compute_E.simple(phylo, times_shared, distances_phylo, process, params_old, masque_data = c(rep(TRUE, attr(params_old, "p_dim") * length(phylo$tip.label)), rep(FALSE, attr(params_old, "p_dim") * phylo$Nnode)), F_moments, Y_data_vec_known, miss = rep(FALSE, attr(params_old, "p_dim") * length(phylo$tip.label)), Y_data, U_tree, ...)simulatecompute_variance_covariancecompute_mean_variance.simple. It uses functions
extract.variance_covariance, extract.covariance_parents, and
extract_simulate_internal to extract the needed quantities from these objects.