enlight.PhyloEM takes an object of class PhyloEM,
and returns the same object, without saving the quantities that can be easily
re-computed using function imputed_traits.PhyloEM.
enlight(x)# S3 method for PhyloEM
enlight(x)
Same as entry, lighter.
an object of class PhyloEM.
enlight(PhyloEM): PhyloEM object
The resulting object can be much lighter, saving a lot of memory space, but each
call to the function imputed_traits.PhyloEM will be longer. As
function plot.PhyloEM relies on this function, this makes the
plotting also longer.
This has the same effect as setting the option "light_result=TRUE" in the
call of PhyloEM.
PhyloEM, imputed_traits.PhyloEM,
plot.PhyloEM