This function takes an object of class PhyloEM, result of function
PhyloEM, and return the values of the model selection criterion
for each value of K.
get_criterion(res, method.selection = NULL)an object of class PhyloEM, result of function
PhyloEM.
select the parameters to plot. One of "LINselect", "DDSE",
"Djump" or "likelihood" (for un-penalized likelihood). Default to "LINselect". See
params_process.PhyloEM.
A named vector with the values of the criterion for each number of shift K.