init.compute_betas_from_shifts initialize the vector of optimal values at nodes and
tips, with the value at the root.
init.compute_betas_from_shifts(phy, optimal.value, ...)Input tree.
the optimal value at the root of the tree
Matrix of size (nNodes + ntaxa)x1 of NAs, with the optimal value at the root.
This function is used in function compute_betas_from_shifts_from_shifts and is designed to
furnish function update.compute_betas_from_shifts with the right structure of data.