log_likelihood computes the log likelihood of some parameters.
log_likelihood(x, ...)# S3 method for params_process
log_likelihood(x, Y_data, phylo, ...)
# S3 method for PhyloEM
log_likelihood(x, ...)
an object of class params_process or PhyloEM.
for a PhyloEM object, further arguments to be passed on to
params_process.PhyloEM (to choose which parameters to extract from
the results, see documentation of this function).
matrix of data at the tips, size p x ntaxa. Each line is a trait, and each column is a tip. The column names are checked against the tip names of the tree.
a phylogenetic tree, class phylo.
incidence.matrix.full. Can be specified to avoid extra computations.
The log likelihood of the data with the provided parameters on the tree.
params_process: params_process object
PhyloEM: PhyloEM object