update.incidence.matrix.full updates the matrix initialized in
init.incidence.matrix.full for the computation of the incidence matrix
in incidence.matrix.full.
update.incidence.matrix.full(daughtersParams, parent, ...)Vector of length ntaxa + Nnode, indicating to which lineages the branch above the current node belongs to.
: rows of updated matrix corresponding to the daughters of the current node.
A node belongs to all the lineages of its daughters.