update.parsimonyNumber compute the line vector of a parent node, given
the vectors of its daughters.
update.parsimonyNumber(daughters, daughtersParams, cost, ...)parsimonyCost).compute_state_filter to find all the admissible
states of the daughters, given a starting state for the parent.